@@ -102,7 +102,7 @@ def _validate_sizes(object_size, part_size):
             )
         if part_size > MAX_PART_SIZE:
             raise ValueError(
-                f"part size {part_size} is not supported; minimum allowed 5GiB",
+                f"part size {part_size} is not supported; maximum allowed 5GiB",
             )
 
     if object_size >= 0:
@@ -255,7 +255,9 @@ def md5sum_hash(data):
     if data is None:
         return None
 
-    hasher = hashlib.md5()
+    # indicate md5 hashing algorithm is not used in a security context.
+    # Refer https://bugs.python.org/issue9216 for more information.
+    hasher = hashlib.new("md5", usedforsecurity=False)
     hasher.update(data.encode() if isinstance(data, str) else data)
     md5sum = base64.b64encode(hasher.digest())
     return md5sum.decode() if isinstance(md5sum, bytes) else md5sum
@@ -648,7 +650,7 @@ class Worker(Thread):
         self.start()
 
     def run(self):
-        """ Continously receive tasks and execute them """
+        """ Continuously receive tasks and execute them """
         while True:
             task = self._tasks_queue.get()
             if not task:
